<?php

declare(strict_types=1);

namespace Drupal\opc\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup as TM;
use Drupal\Core\Url;
use Drupal\opc\Contract\OpcacheInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * {@selfdoc}
 */
final class ResetForm extends ConfirmFormBase {

  /**
   * {@selfdoc}
   */
  public function __construct(private readonly OpcacheInterface $opcache) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self($container->get('opc.opcache'));
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'opc_opcache_reset';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion(): TM {
    return new TM('Are you sure?');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription(): TM {
    return new TM('This will reset the entire opcode cache.');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return new TM('Reset');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl(): Url {
    return new Url('opc.opcache_status');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->opcache->reset();
    $this->messenger()->addStatus(new TM('Opcache has been reset.'));
    $form_state->setRedirectUrl(new Url('opc.opcache_status'));
  }

}
